==> richfaces-distribution-4.0.0.20101004-M3.zip: org/richfaces/application/MessageFactory.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010, Red Hat, Inc. and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.richfaces.application;

import javax.faces.application.FacesMessage;
import javax.faces.application.FacesMessage.Severity;
import javax.faces.context.FacesContext;

/**
 * @author Nick Belaevski
 * 
 */
public interface MessageFactory {

    public FacesMessage createMessage(FacesContext facesContext, Enum<?> messageKey, Object... args);

    public FacesMessage createMessage(FacesContext facesContext, Severity severity, Enum<?> messageKey, Object... args);

    public String getMessageText(FacesContext facesContext, Enum<?> messageKey, Object... args);
    
}

==> richfaces-distribution-4.3.0.20121214-M3.zip: org/richfaces/application/MessageFactory.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2010, Red Hat, Inc. and individual contributors
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.richfaces.application;

import javax.faces.application.FacesMessage;
import javax.faces.application.FacesMessage.Severity;
import javax.faces.context.FacesContext;

/**
 * @author Nick Belaevski
 *
 */
public interface MessageFactory {
    FacesMessage createMessage(FacesContext facesContext, Enum<?> messageKey, Object... args);

    FacesMessage createMessage(FacesContext facesContext, Severity severity, Enum<?> messageKey, Object... args);

    String getMessageText(FacesContext facesContext, Enum<?> messageKey, Object... args);

    String getMessageFormat(FacesContext facesContext, Enum<?> messageKey);
}
